"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
module.exports = function (
// Object of sites
sites, 
// Specific devices if different to default
inputDevices) {
    if (inputDevices === void 0) { inputDevices = utils_1.defaultDevices; }
    // Collate PLaywright projects
    var projects = [];
    // Loop through defined sites
    for (var _i = 0, sites_1 = sites; _i < sites_1.length; _i++) {
        var site = sites_1[_i];
        var devices = inputDevices;
        if (site.devices) {
            devices = site.devices;
            delete site.devices;
        }
        if (devices.length > 0) {
            // Create a site for each default device
            for (var _a = 0, devices_1 = devices; _a < devices_1.length; _a++) {
                var device = devices_1[_a];
                projects.push((0, utils_1.convertSiteToPlaywrightProject)(site, device));
            }
        }
        else {
            projects.push((0, utils_1.convertSiteToPlaywrightProject)(site));
        }
    }
    // Return Playwright configuration
    return {
        /* Run tests in files in parallel */
        fullyParallel: true,
        /* Fail the build on CI if you accidentally left test.only in the source code. */
        forbidOnly: !!process.env.CI,
        /* Retry on CI only */
        retries: process.env.CI ? 2 : 0,
        /* Opt out of parallel tests on CI. */
        workers: process.env.CI ? 1 : undefined,
        /* Reporter to use. See https://playwright.dev/docs/test-reporters */
        reporter: [
            ['list', { printSteps: true }],
            ['html']
        ],
        /* Shared settings for all the projects below. See https://playwright.dev/docs/api/class-testoptions. */
        use: {
            /* Base URL to use in actions like `await page.goto('/')`. */
            // baseURL: 'http://127.0.0.1:3000',
            /* Collect trace when retrying the failed test. See https://playwright.dev/docs/trace-viewer */
            trace: 'on-first-retry',
            screenshot: 'only-on-failure'
        },
        /* Configure projects for major browsers */
        projects: projects
    };
};
